@@ -2,3 +2,5 @@
 from aiger_coins.distributions import coin, dist, binomial
 from aiger_coins.dice import Coin, Distribution
 from aiger_coins.mdp import MDP, circ2mdp, dist2mdp
+from aiger_coins.pcirc import *
+from aiger_coins.random_var import *
